package com.persagy.server.syn.models.tools

import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import com.persagy.base.extensions.toInt
import com.persagy.database.SFilter
import com.persagy.mybatis.SMybatisDao
import com.persagy.server.datacenter.models.entities.assistant.PointPosition
import com.persagy.server.datacenter.models.entities.dictnew.DefFuncId
import com.persagy.server.datacenter.models.entities.objects.Floor
import com.persagy.server.syn.Opts
import com.persagy.service.SObjectService
import com.persagy.service.utils.SSpringContextUtil

/**
 * 楼层 - 中台转数据中心
 *
 * @author wx  <zhangweixin@sagacloud.com>
 * @date  2020/10/19 15:01
 */
object FloorUtil {
    /** 信息点 */
    private val dictDefFuncIdService = SObjectService(SMybatisDao(DefFuncId::class.java))
    /** 配置 */
    private val opts: Opts by lazy {
        SSpringContextUtil.getBean(Opts::class.java) as Opts
    }

    /**
     * 楼层数据转换
     */
    fun floorSyn(projectId: String,groupCode: String, mapObj: HashMap<String, Any?>): Floor {
        /** 查建楼层型字典 */
        val dictDefFuncIdList = dictDefFuncIdService.select(SFilter.eq("groupCode", groupCode), SFilter.eq("classCode", "floor")).exec()
        val mapEx = HashMap<String, Any?>()
        val mapCode = HashMap<String, Any?>()

        for (explainProject in dictDefFuncIdList) {
            mapEx[explainProject.code!!] = explainProject.firstName
            if (!explainProject.secondName.isNullOrEmpty()) {
                mapCode[explainProject.code!!] = explainProject.secondName
            }
        }

        /** 结构信息 */
        val structureInfo = HashMap<String, Any?>()
        /** 人员信息 */
        val peopleInfo = HashMap<String, Any?>()
        /** 工作历信息 */
        val workCalendar = HashMap<String, Any?>()

        val floor = Floor()
        floor.projectId = projectId
        /** id 是否存在 */
        val containsKeyId = mapObj.containsKey("id")
        if(containsKeyId){
            floor.id = mapObj["id"].toString()
        }
        /** name 是否存在 */
        val containsKeyName = mapObj.containsKey("name")
        if(containsKeyName){
            floor.name = mapObj["name"].toString()
        }

        for (key in mapObj.keys) {
            val containsKey = mapEx.containsKey(key)
            if (containsKey) {
                val value = mapEx[key]
                if (value == opts.StructureInfo) {
                    /** 结构信息 */
                    structureInfo[key] = mapObj[key]
                } else if (value == opts.PeopleInfo) {
                    /** 人员信息 */
                    peopleInfo[key] = mapObj[key]
                } else if (value == "工作历信息") {
                    workCalendar[key] = mapObj[key]
                } else {
                    when (key) {
                        "localId" -> floor.localId = mapObj[key].toString()
                        "localName" -> floor.localName = mapObj[key].toString()
                        "bimId" -> floor.bimId = mapObj[key].toString()
                        "defaultQRCode" -> floor.defaultQRCode = mapObj[key].toString()
                        "qRCodePic" -> floor.qRCodePic = mapObj[key].toString()
                        "bimIdPre"  -> floor.bimIdPre = mapObj[key].toString()
                        "modelId"  ->  floor.modelId = mapObj[key].toString()
                        "bimLocation" -> floor.bimLocation = mapObj[key].toString()
                        "permanentPeopleNum" -> floor.permanentPeopleNum = mapObj[key]?.toInt()
                        "floorIdentity" -> floor.floorIdentity = mapObj[key].toString()
                        "floorSequenceId" -> {
                            if (!mapObj[key].toString().isNullOrEmpty() && mapObj[key].toString() != "null") {
                                floor.floorSequenceId = mapObj[key]?.toString()?.toInt()
//                                logger.debug("FloorSequenceID =${infos[key]!!.toString().toInt()}")
                            }
                        }
                        "outline" -> {
                            try {
                                val type = object : TypeToken<ArrayList<PointPosition>>() {
                                }.getType()
                                var outline=  Gson().fromJson<ArrayList<PointPosition>>(mapObj[key].toString(),type)
                                floor.outline = outline
                            } catch (e: Exception) {
                                e.printStackTrace()
                            }
                        }
                    }
                }
            }
        }
        if (structureInfo.size > 0) {
            floor.structureInfo = structureInfo
        }
        if (peopleInfo.size > 0) {
            floor.peopleInfo = peopleInfo
        }
        if (workCalendar.size > 0) {
            floor.workCalendar = workCalendar
        }

        return floor
    }

}